package com.yaoyicloud.tools;

import cn.hutool.core.util.StrUtil;
import com.deepoove.poi.data.NumberingFormat;
import com.deepoove.poi.data.NumberingRenderData;
import com.deepoove.poi.data.ParagraphRenderData;
import com.deepoove.poi.data.PictureType;
import com.deepoove.poi.data.Pictures;
import com.deepoove.poi.data.Texts;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class ProcessDataUtil {
    public void processLink(Map<String, Object> data, String key) {
        String link = (String) data.get(key);
        if (StrUtil.isNotBlank(link)) {
            data.put(key, Texts.of(link).link(link).create());
        }
    }
    public void processImageListToNumberedRenderData(String key, Map<String, Object> data) {
        // 从data中获取原始图片数据列表
        List<Map<String, Object>> rawImageDataList = (List<Map<String, Object>>) data.get(key);

        // 处理空数据情况
        if (rawImageDataList == null || rawImageDataList.isEmpty()) {
            String textKey = key + "Text";
            if (data.containsKey(textKey)) {
                return;
            }
        }
        // 处理非空图片数据
        List<ParagraphRenderData> paragraphImages = new ArrayList<>();
        for (Map<String, Object> imageInfo : rawImageDataList) {
            ParagraphRenderData paragraph = new ParagraphRenderData();
            // 提取Base64数据和文件扩展名
            String base64 = (String) imageInfo.get("base64");
            String url = (String) imageInfo.get("url");
            String fileExtension = (String) imageInfo.get("fileExtension");
            Integer width = (Integer) imageInfo.get("width");
            Integer height = (Integer) imageInfo.get("height");

            // 确定图片类型（默认为PNG）
            PictureType pictureType = this.determinePictureType(fileExtension);

            // 添加图片到段落渲染数据
            paragraph.addPicture(Pictures.ofBase64(base64, pictureType)
                    .size(width, height)
                    .create());

            paragraphImages.add(paragraph);

        }
        NumberingFormat numberingFormat = new NumberingFormat(1, "");
        NumberingRenderData numberedImages = new NumberingRenderData(numberingFormat, paragraphImages);
        data.put(key, numberedImages);
    }
    // 辅助方法：根据文件扩展名确定图片类型
    private PictureType determinePictureType(String fileExtension) {
        if (fileExtension == null) {
            return PictureType.PNG;
        }
        String ext = fileExtension.toLowerCase();
        // 提取扩展名部分（去除前缀点）
        String normalizedExt = ext.startsWith(".")
                ? ext.substring(1)
                : ext;
        return switch (normalizedExt) {
            case "jpg", "jpeg" -> PictureType.JPEG;
            case "gif" -> PictureType.GIF;
            case "bmp" -> PictureType.BMP;
            case "tiff" -> PictureType.TIFF;
            default -> PictureType.PNG; // 默认返回 PNG
        };
    }
}
